@@ -24,6 +24,10 @@
  * the source code for OpenSSL in the source distribution.
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
 #include <string.h>
 
@@ -34,7 +38,11 @@
 # include <security/pam_appl.h>
 #endif
 
-#include <security/pam_misc.h>
+#ifdef HAVE_OPENPAM_H
+# include <security/openpam.h>
+#elif defined (HAVE_PAM_MISC_H)
+# include <security/pam_misc.h>
+#endif
 
 #include <pwd.h>
 #include <grp.h>
@@ -42,6 +50,7 @@
 #include <sys/types.h>
 
 #include <libwzd-core/wzd_backend.h>
+#include <libwzd-core/wzd_user.h>
 #include <libwzd-core/wzd_debug.h>
 
 #define	HARD_DEF_USER_MAX	64
@@ -230,12 +239,12 @@ gid_t FCN_FIND_GROUP(const char *name, wzd_group_t * group)
 }
 
 /* if user does not exist, add it */
-int FCN_MOD_USER(const char *name, wzd_user_t * user, unsigned long mod_type)
+int FCN_MOD_USER(uid_t uid, wzd_user_t * user, unsigned long mod_type)
 {
   return 1;
 }
 
-int FCN_MOD_GROUP(const char *name, wzd_group_t * group, unsigned long mod_type)
+int FCN_MOD_GROUP(gid_t gid, wzd_group_t * group, unsigned long mod_type)
 {
   return 1;
 }
@@ -281,7 +290,7 @@ static int _pam_adduser(const char *name, int uid, const char *homedir)
 
   strncpy(user_pool[_user_count].username, name, sizeof(user_pool[_user_count].username));
   user_pool[_user_count].uid = uid;
-  strncpy(user_pool[_user_count].ip_allowed[0],"*",2);
+  ip_add_check(&user_pool[_user_count].ip_list,"*",1 /* is allowed */);
   strncpy(user_pool[_user_count].rootpath, homedir, sizeof(user_pool[_user_count].rootpath));
   user_pool[_user_count].userperms = 0xffffffff;
   /* root is always siteop .. */
