@@ -39,62 +39,19 @@
 #include <libwzd-base/wzd_strlcat.h>
 
 #include <libwzd-core/wzd_backend.h>
+#include <libwzd-core/wzd_group.h>
+#include <libwzd-core/wzd_log.h>
 #include <libwzd-core/wzd_misc.h> /* win_normalize */
 
 #include <libwzd-core/wzd_debug.h>
 
 #include "libpgsql.h"
 
-int _group_update_ip(uid_t ref, wzd_group_t * group);
+static int _group_update_ip(uid_t ref, wzd_group_t * group);
 
-gid_t group_get_ref(const char * name, unsigned int ref);
+static unsigned int group_get_ref(gid_t gid, unsigned int ref);
 
 
-gid_t FCN_FIND_GROUP(const char *name, wzd_group_t * group)
-{
-  char *query;
-  gid_t gid;
-  PGresult * res;
-
-  if (!wzd_pgsql_check_name(name)) return (gid_t)-1;
-
-  query = malloc(512);
-  snprintf(query, 512, "SELECT * FROM groups WHERE groupname='%s'", name);
-
-  res = PQexec(pgconn, query);
-
-  if (!res || PQresultStatus(res) != PGRES_TUPLES_OK) {
-    free(query);
-    _wzd_pgsql_error(__FILE__, __FUNCTION__, __LINE__);
-    return (gid_t)-1;
-  }
-
-  free(query);
-  gid = (gid_t)-1;
-
-  /** no !! this returns the number of COLUMNS (here, 14) */
-/*  if (mysql_field_count(&mysql) == 1)*/
-  {
-    int num_fields;
-
-    if ( PQntuples(res) != 1 ) {
-      /* 0 or more than 1 result */
-      PQclear(res);
-      return (gid_t)-1;
-    }
-
-    num_fields = PQnfields(res);
-
-    gid = atoi(PQgetvalue(res,0,GCOL_GID));
-
-    PQclear(res);
-
-  }/* else  // no such user
-    return -1;*/
-
-  return gid;
-}
-
 #define APPEND_STRING_TO_QUERY(format, s, query, query_length, mod, modified) \
   do { \
     snprintf(mod, 512, format, s); \
@@ -102,31 +59,39 @@ gid_t FCN_FIND_GROUP(const char *name, wzd_group_t * group)
     modified = 1; \
   } while (0);
 
-int wpgsql_mod_group(const char *name, wzd_group_t * group, unsigned long mod_type)
+int wpgsql_mod_group(gid_t gid, wzd_group_t * group, unsigned long mod_type)
 {
   char *query, *mod;
-  PGresult * res;
-  int modified = 0;
+  int modified = 0, update_registry = 0;
   unsigned int query_length = 512;
   gid_t ref = 0;
-  unsigned int i;
+  wzd_group_t * registered_group;
+  gid_t reg_gid;
+  struct wzd_ip_list_t * current_ip;
 
-  if (!group) { /* delete user permanently */
+  if (!group) { /* delete group permanently */
     query = malloc(2048);
     /* we don't care about the results of the queries */
-    ref = group_get_ref(name, 0);
+    ref = group_get_ref(gid, 0);
     if (ref) {
       _wzd_run_update_query(query, 2048, "DELETE FROM groupip WHERE ref=%d", ref);
       _wzd_run_update_query(query, 2048, "DELETE FROM ugr WHERE gref=%d", ref);
     }
-    _wzd_run_update_query(query, 2048, "DELETE FROM groups WHERE groupname='%s'", name);
+    _wzd_run_update_query(query, 2048, "DELETE FROM groups WHERE gid='%d'", gid);
     free(query);
 
+    /** \todo use group_get_id_by_name */
+    registered_group = group_get_by_id(gid);
+    if (registered_group != NULL) {
+      registered_group = group_unregister(registered_group->gid);
+      group_free(registered_group);
+    }
+
     return 0;
   }
 
   /* search if group exists, if not, create it */
-  ref = group_get_ref(name,0);
+  ref = group_get_ref(gid,0);
 
   if (ref) { /* group exists, just modify fields */
     query = malloc(query_length);
@@ -162,9 +127,10 @@ int wpgsql_mod_group(const char *name, wzd_group_t * group, unsigned long mod_ty
     if (mod_type & _GROUP_NUMLOGINS)
       APPEND_STRING_TO_QUERY("num_logins='%u' ", group->num_logins, query, query_length, mod, modified);
 
-    /* XXX FIXME IP requires some work ... */
-    if (mod_type & _GROUP_IP)
-      _group_update_ip(ref,group);
+    if (mod_type & _GROUP_IP) {
+      _group_update_ip(ref,group); /** \todo XXX test return ! */
+      update_registry = 1;
+    }
 
     if (mod_type & _GROUP_RATIO)
       APPEND_STRING_TO_QUERY("ratio='%u' ", group->ratio, query, query_length, mod, modified);
@@ -172,21 +138,39 @@ int wpgsql_mod_group(const char *name, wzd_group_t * group, unsigned long mod_ty
 
     if (modified)
     {
-      snprintf(mod, 512, " WHERE groupname='%s'", name);
+      snprintf(mod, 512, " WHERE gid='%d'", gid);
       query = _append_safely_mod(query, &query_length, mod, 0);
 
-	  res = PQexec(pgconn, query);
-
-      if (!res || PQresultStatus(res) != PGRES_COMMAND_OK) {
-        _wzd_pgsql_error(__FILE__, __FUNCTION__, __LINE__);
+      if (_wzd_run_update_query(query,query_length,query) != 0)
         goto error_mod_group_free;
-      }
-
-      PQclear(res);
 
       free(mod); free(query);
+
+      update_registry = 1;
+    }
+
+    if (update_registry) {
+      registered_group = group_get_by_id(group->gid);
+      if (registered_group != NULL) {
+        out_log(LEVEL_FLOOD,"PGSQL updating registered group %s\n",group->groupname);
+
+        if (group_update(registered_group->gid,group)) {
+          out_log(LEVEL_HIGH,"ERROR PGSQL Could not update group %s %d\n",group->groupname,group->gid);
+          return -1;
+        }
+      } else {
+        if (group->gid != (gid_t)-1) {
+          reg_gid = group_register(group,1 /* XXX backend id */);
+          if (reg_gid != group->gid) {
+            out_log(LEVEL_HIGH,"ERROR PGSQL Could not register group %s %d\n",group->groupname,group->gid);
+            return -1;
+          }
+        }
+      }
+
+
       return 0;
-    } /* if (modified) */
+    } /* if (update_registry) */
 
     free(mod); free(query);
     return -1;
@@ -194,12 +178,18 @@ int wpgsql_mod_group(const char *name, wzd_group_t * group, unsigned long mod_ty
 
   /* create new group */
 
+  registered_group = group_get_by_id(gid);
+  if (registered_group) {
+    out_log(LEVEL_INFO,"WARNING: group %s is not present in DB but already registered\n",group->groupname);
+    return -1;
+  }
+
   /* Part 1, Group */
   query = malloc(2048);
   mod = NULL;
 
-  /* XXX FIXME find a free gid !! */
-  group->gid = 155;
+  /* sequence will find a free uid */
+  group->gid = INVALID_GROUP;
 
   if (_wzd_run_update_query(query, 2048, "INSERT INTO groups (groupname,gid,defaultpath,tagline,groupperms,max_idle_time,num_logins,max_ul_speed,max_dl_speed,ratio) VALUES ('%s',nextval('groups_gid_seq'),'%s','%s',CAST (X'%lx' AS integer),%u,%u,%lu,%lu,%u)",
       group->groupname,
@@ -211,16 +201,40 @@ int wpgsql_mod_group(const char *name, wzd_group_t * group, unsigned long mod_ty
       ))
     goto error_group_add;
 
-  ref = group_get_ref(group->groupname,0);
+  ref = group_get_ref(group->gid,0);
   if (!ref) goto error_group_add;
 
   /* Part 2, IP */
-  for ( i=0; i<HARD_IP_PER_GROUP; i++ )
-    if (group->ip_allowed[i][0] != '\0') {
-      if (_wzd_run_update_query(query, 2048, "INSERT INTO groupip (ref,ip) VALUES (%u,'%s')",
-            ref, group->ip_allowed[i]))
-        goto error_group_add;
+  for (current_ip=group->ip_list; current_ip != NULL; current_ip=current_ip->next_ip) {
+    if (_wzd_run_update_query(query, 2048, "INSERT INTO groupip (ref,ip) VALUES (%u,'%s')",
+          ref, current_ip->regexp))
+      goto error_group_add;
+  }
+
+  /* get generated gid from DB */
+  {
+    PGresult * res;
+    if ( (res = _wzd_run_select_query(query,2048,"SELECT groups.gid FROM groups WHERE ref='%d'",ref)) == NULL )
+      goto error_group_add;
+    if ( PQntuples(res) != 1 ) {
+      PQclear(res);
+      goto error_group_add;
     }
+    if ( wzd_row_get_uint(&group->gid, res, 0 /* only 1 column */) ) {
+      PQclear(res);
+      goto error_group_add;
+    }
+    PQclear(res);
+  }
+
+  /** \todo check values and register group */
+
+  reg_gid = group_register(group,1 /* XXX backend id */);
+  if (reg_gid != group->gid) {
+    out_log(LEVEL_HIGH,"ERROR PGSQL Could not register group %s %d\n",group->groupname,group->gid);
+    /** \todo free group and return INVALID_USER */
+    goto error_group_add;
+  }
 
   free(query);
 
@@ -228,7 +242,7 @@ int wpgsql_mod_group(const char *name, wzd_group_t * group, unsigned long mod_ty
 
 error_group_add:
   /* we don't care about the results of the queries */
-  ref = group_get_ref(group->groupname,0);
+  ref = group_get_ref(group->gid,0);
   if (ref) {
     _wzd_run_update_query(query, 2048, "DELETE FROM groupip WHERE ref=%d", ref);
     _wzd_run_update_query(query, 2048, "DELETE FROM ugr WHERE gref=%d", ref);
@@ -236,6 +250,14 @@ error_group_add:
   _wzd_run_update_query(query, 2048, "DELETE FROM groups WHERE groupname='%s'", group->groupname);
   free(query);
 
+  /** \todo use group_get_id_by_name */
+  registered_group = group_get_by_id(gid);
+  if (registered_group != NULL) {
+    registered_group = group_unregister(registered_group->gid);
+    group_free(registered_group);
+  }
+
+
   return -1;
 
 error_mod_group_free:
@@ -245,109 +267,96 @@ error_mod_group_free:
   return -1;
 }
 
-int _group_update_ip(uid_t ref, wzd_group_t * group)
+/** Update ip for a specific group using the following:
+ * get stored ip list For each ip of modified group, try to find it
+ * for the stored group: if not present, add it. For each ip of the
+ * stored group, try to find it in the modified group: if not present,
+ * delete it.
+ * \return O if ok
+ */
+static int _group_update_ip(gid_t ref, wzd_group_t * group)
 {
-  char *query;
+  char query[512];
   PGresult * res;
-  unsigned int i;
-  int index;
-  char ip_list[HARD_IP_PER_GROUP][MAX_IP_LENGTH];
+  int i_stored;
+  int found;
   int ret;
+  const char *ip_stored;
+  struct wzd_ip_list_t * current_ip;
 
   if (!ref) return -1;
 
-  query = malloc(512);
-  snprintf(query, 512, "SELECT groupip.ip FROM groupip WHERE ref=%d", ref);
+  /* extract ip list for group */
+  if ( (res = _wzd_run_select_query(query,512,"SELECT groupip.ip FROM groupip WHERE ref=%d",ref)) == NULL) return 0;
 
-  res = PQexec(pgconn, query);
-
-  if (!res || PQresultStatus(res) != PGRES_TUPLES_OK) {
-    free(query);
-    _wzd_pgsql_error(__FILE__, __FUNCTION__, __LINE__);
-    return 0;
-  }
-
-  for (i=0; i<HARD_IP_PER_GROUP; i++)
-    ip_list[i][0] = '\0';
-
-  i = 0;
-  for (index=0; index<PQntuples(res); index++) {
-    strncpy(ip_list[i],PQgetvalue(res,0,0),MAX_IP_LENGTH);
-    i++;
-    if (i >= HARD_IP_PER_GROUP) {
-      /** too many ip in db ?! - ignoring others */
-      break;
-    }
-  }
-
-  /* compare the two sets of ip */
-  for (i=0; i<HARD_IP_PER_GROUP; i++) {
-    ret = 1;
-    if (strcmp(group->ip_allowed[i],ip_list[i])!=0) {
-      /* check for injections in ip */
-      if (!wzd_pgsql_check_name(ip_list[i]) || !wzd_pgsql_check_name(group->ip_allowed[i])) {
-        /* print error message ? */
+  /* find NEW ip */
+  for (current_ip=group->ip_list; current_ip != NULL; current_ip=current_ip->next_ip) {
+    found = 0;
+    for (i_stored=0; i_stored<PQntuples(res); i_stored++) {
+      ip_stored = PQgetvalue(res,i_stored,0);
+      if (strcmp(current_ip->regexp,ip_stored)==0) {
+        found = 1;
         break;
       }
-      if (group->ip_allowed[i][0]=='\0')
-        ret = _wzd_run_delete_query(query,512,"DELETE FROM groupip WHERE groupip.ref=%d AND groupip.ip='%s'",ref,ip_list[i]);
-      else {
-        if (ip_list[i][0]=='\0')
-          ret = _wzd_run_insert_query(query,512,"INSERT INTO groupip (ref,ip) VALUES (%d,'%s')",ref,group->ip_allowed[i]);
-        else
-          ret = _wzd_run_update_query(query,512,"UPDATE groupip SET ip='%' WHERE groupip.ref=%d AND groupip.ip='%s'",ip_list[i],ref,group->ip_allowed[i]);
+    }
+    if (found == 0) {
+      ret = _wzd_run_insert_query(query,512,"INSERT INTO groupip (ref,ip) VALUES (%d,'%s')",ref,current_ip->regexp);
+      if (ret) {
+        PQclear(res);
+        return -1;
       }
     }
-    else
-      ret = 0;
-    if (ret) {
-      /* print error message ? */
-      break;
+  }
+
+  /* find DELETED ip */
+  for (i_stored=0; i_stored<PQntuples(res); i_stored++) {
+    ip_stored = PQgetvalue(res,i_stored,0);
+    for (current_ip=group->ip_list; current_ip != NULL; current_ip=current_ip->next_ip) {
+      found = 0;
+      if (strcmp(current_ip->regexp,ip_stored)==0) {
+        found = 1;
+        break;
+      }
+    }
+    if (found == 0) {
+      ret = _wzd_run_delete_query(query,512,"DELETE FROM groupip WHERE groupip.ref=%d AND groupip.ip='%s'",ref,ip_stored);
+      if (ret) {
+        PQclear(res);
+        return -1;
+      }
     }
   }
 
   PQclear(res);
-  free(query);
-
   return 0;
 }
 
 
-gid_t group_get_ref(const char * name, unsigned int ref)
+static unsigned int group_get_ref(gid_t gid, unsigned int ref)
 {
-  char *query;
-  gid_t gid=0;
+  char query[512];
+  unsigned int ret_ref=0;
   unsigned long ul;
   int index;
   char *ptr;
   PGresult * res;
 
-  if (!wzd_pgsql_check_name(name)) return 0;
+  /** \bug XXX FIXME 0 is a valid gid - should it be -1 ? */
 
   if (ref) return ref;
 
-  query = malloc(512);
-  snprintf(query, 512, "SELECT groups.ref FROM groups WHERE groupname='%s'", name);
-
-  res = PQexec(pgconn, query);
-
-  if (!res || PQresultStatus(res) != PGRES_TUPLES_OK) {
-    free(query);
-    _wzd_pgsql_error(__FILE__, __FUNCTION__, __LINE__);
-    return 0;
-  }
+  if ( (res = _wzd_run_select_query(query,512,"SELECT groups.ref FROM groups WHERE gid='%d'",gid)) == NULL) return 0;
 
   for (index=0; index<PQntuples(res); index++) {
     ul = strtoul(PQgetvalue(res,0,0), &ptr, 0);
     if (ptr && *ptr == '\0') {
-      gid = (gid_t)ul;
+      ret_ref = (unsigned int)ul;
     }
 
   }
 
   PQclear(res);
-  free(query);
 
-  return gid;
+  return ret_ref;
 }
 
