@@ -34,7 +34,7 @@
 #define __WZD_ALL__
 
 #ifdef HAVE_CONFIG_H
-#include "../config.h"
+#include "config.h"
 #endif
 
 #include <stdio.h>
@@ -72,7 +72,7 @@
 #define DL_PREFIX
 #endif
 
-
+#include <libwzd-base/strpcpy.h>
 
 #include "wzd_structs.h"
 
@@ -86,6 +86,7 @@
 #include "wzd_events.h"
 #include "wzd_file.h"
 #include "wzd_fs.h"
+#include "wzd_group.h"
 #include "wzd_libmain.h"
 #include "wzd_log.h"
 #include "wzd_messages.h"
@@ -99,6 +100,7 @@
 #include "wzd_socket.h"
 #include "wzd_string.h"
 #include "wzd_threads.h"
+#include "wzd_user.h"
 #include "wzd_utf8.h"
 #include "wzd_vars.h"
 #include "wzd_vfs.h"
@@ -111,7 +113,7 @@
 #else /* WZD_USE_PCH */
 
 #ifdef HAVE_CONFIG_H
-#include "../config.h"
+#include "config.h"
 #endif
 
 #endif /* WZD_USE_PCH */
