@@ -56,6 +56,12 @@ static void _command_free(wzd_command_t *command)
   free(command);
 }
 
+/** \brief Initialize storage for server commands
+ *
+ * \param[out] _ctable Pointer to the allocated hash table
+ *
+ * \return 0 if ok
+ */
 int commands_init(CHTBL ** _ctable)
 {
   if (*_ctable) {
@@ -73,6 +79,10 @@ int commands_init(CHTBL ** _ctable)
   return 0;
 }
 
+/** \brief Destroy stored commands, and free memory used for commands
+ *
+ * \param[in] _ctable Hash table containing commands
+ */
 void commands_fini(CHTBL * _ctable)
 {
   if (!_ctable) return;
@@ -82,6 +92,17 @@ void commands_fini(CHTBL * _ctable)
   _ctable = NULL;
 }
 
+/** \brief Add a new FTP command, linked to a C function
+ *
+ * \param[in] _ctable Hash table containing commands
+ * \param[in] name The FTP command (for ex, XCRC). For a site command, append command
+ * name with a space: SITE_HELP
+ * \param[in] command The function which will be executed when receiving the FTP command
+ * \param[in] help A pointer to a help function (not used at the moment)
+ * \param[in] id A unique identifier (32 bits unsigned integer) for the command (see \ref wzd_token_t)
+ *
+ * \note Command names are case insensitive, and must be valid ASCII
+ */
 int commands_add(CHTBL * _ctable,
     const char *name,
     wzd_function_command_t command,
@@ -119,6 +140,16 @@ int commands_add(CHTBL * _ctable,
   return 0;
 }
 
+/** \brief Add a new FTP command, linked to an external program (for ex, a perl module)
+ *
+ * \param[in] _ctable Hash table containing commands
+ * \param[in] name The FTP command (for ex, XCRC). For a site command, append command
+ * name with a space: SITE_HELP
+ * \param[in] external_command The application which will be executed when receiving the FTP command.
+ * The application can use protocols (see \ref hook_add_protocol)
+ *
+ * \note Command names are case insensitive, and must be valid ASCII
+ */
 int commands_add_external(CHTBL * _ctable,
     const char *name,
     const wzd_string_t *external_command)
@@ -158,6 +189,12 @@ int commands_add_external(CHTBL * _ctable,
   return -1;
 }
 
+/** \brief Add default FTP commands to hash table
+ *
+ * \param[in] _ctable Hash table containing commands
+ *
+ * \return 0 if ok
+ */
 int commands_add_defaults(CHTBL * _ctable)
 {
   if (!_ctable) return -1;
@@ -212,36 +249,37 @@ int commands_add_defaults(CHTBL * _ctable)
   if (commands_add(_ctable,"mic",do_mic,NULL,TOK_MIC)) return -1;
 #endif
 
-  if (commands_add(_ctable,"site_addip",do_site_addip,NULL,TOK_SITE_ADDIP)) return -1;
-  if (commands_add(_ctable,"site_adduser",do_site_adduser,NULL,TOK_SITE_ADDUSER)) return -1;
+  if (commands_add(_ctable,"site_addip",do_site_addip,do_site_help_addip,TOK_SITE_ADDIP)) return -1;
+  if (commands_add(_ctable,"site_adduser",do_site_adduser,do_site_help_adduser,TOK_SITE_ADDUSER)) return -1;
   if (commands_add(_ctable,"site_backend",do_site_backend,NULL,TOK_SITE_BACKEND)) return -1;
   if (commands_add(_ctable,"site_chacl",do_site_chacl,NULL,TOK_SITE_CHACL)) return -1;
-  if (commands_add(_ctable,"site_change",do_site_change,NULL,TOK_SITE_CHANGE)) return -1;
-  if (commands_add(_ctable,"site_changegrp",do_site_changegrp,NULL,TOK_SITE_CHANGEGRP)) return -1;
+  if (commands_add(_ctable,"site_change",do_site_change,do_site_help_change,TOK_SITE_CHANGE)) return -1;
+  if (commands_add(_ctable,"site_changegrp",do_site_changegrp,do_site_help_changegrp,TOK_SITE_CHANGEGRP)) return -1;
   if (commands_add(_ctable,"site_checkperm",do_site_checkperm,NULL,TOK_SITE_CHECKPERM)) return -1;
   if (commands_add(_ctable,"site_chgrp",do_site_chgrp,NULL,TOK_SITE_CHGRP)) return -1;
   if (commands_add(_ctable,"site_chmod",do_site_chmod,NULL,TOK_SITE_CHMOD)) return -1;
   if (commands_add(_ctable,"site_chown",do_site_chown,NULL,TOK_SITE_CHOWN)) return -1;
   if (commands_add(_ctable,"site_chpass",do_site_chpass,NULL,TOK_SITE_CHPASS)) return -1;
-  if (commands_add(_ctable,"site_chratio",do_site_chratio,NULL,TOK_SITE_CHRATIO)) return -1;
+  if (commands_add(_ctable,"site_chratio",do_site_chratio,do_site_help_chratio,TOK_SITE_CHRATIO)) return -1;
   if (commands_add(_ctable,"site_close",do_site,NULL,TOK_SITE_CLOSE)) return -1;
   if (commands_add(_ctable,"site_color",do_site_color,NULL,TOK_SITE_COLOR)) return -1;
-  if (commands_add(_ctable,"site_delip",do_site_delip,NULL,TOK_SITE_DELIP)) return -1;
-  if (commands_add(_ctable,"site_deluser",do_site_deluser,NULL,TOK_SITE_DELUSER)) return -1;
+  if (commands_add(_ctable,"site_delip",do_site_delip,do_site_help_delip,TOK_SITE_DELIP)) return -1;
+  if (commands_add(_ctable,"site_deluser",do_site_deluser,do_site_help_deluser,TOK_SITE_DELUSER)) return -1;
   if (commands_add(_ctable,"site_flags",do_site_flags,NULL,TOK_SITE_FLAGS)) return -1;
   if (commands_add(_ctable,"site_free",do_site_free,NULL,TOK_SITE_FREE)) return -1;
   if (commands_add(_ctable,"site_ginfo",do_site_ginfo,NULL,TOK_SITE_GINFO)) return -1;
-  if (commands_add(_ctable,"site_give",do_site_give,NULL,TOK_SITE_GIVE)) return -1;
-  if (commands_add(_ctable,"site_group",do_site_group,NULL,TOK_SITE_GROUP)) return -1;
-  if (commands_add(_ctable,"site_grpadd",do_site_grpadd,NULL,TOK_SITE_GRPADD)) return -1;
-  if (commands_add(_ctable,"site_grpaddip",do_site_grpaddip,NULL,TOK_SITE_GRPADDIP)) return -1;
-  if (commands_add(_ctable,"site_grpchange",do_site_grpchange,NULL,TOK_SITE_GRPCHANGE)) return -1;
-  if (commands_add(_ctable,"site_grpdel",do_site_grpdel,NULL,TOK_SITE_GRPDEL)) return -1;
-  if (commands_add(_ctable,"site_grpdelip",do_site_grpdelip,NULL,TOK_SITE_GRPDELIP)) return -1;
+  if (commands_add(_ctable,"site_give",do_site_give,do_site_help_give,TOK_SITE_GIVE)) return -1;
+  if (commands_add(_ctable,"site_group",do_site_group,do_site_help_group,TOK_SITE_GROUP)) return -1;
+  if (commands_add(_ctable,"site_grpadd",do_site_grpadd,do_site_help_grpadd,TOK_SITE_GRPADD)) return -1;
+  if (commands_add(_ctable,"site_grpaddip",do_site_grpaddip,do_site_help_grpaddip,TOK_SITE_GRPADDIP)) return -1;
+  if (commands_add(_ctable,"site_grpchange",do_site_grpchange,do_site_help_grpchange,TOK_SITE_GRPCHANGE)) return -1;
+  if (commands_add(_ctable,"site_grpdel",do_site_grpdel,do_site_help_grpdel,TOK_SITE_GRPDEL)) return -1;
+  if (commands_add(_ctable,"site_grpdelip",do_site_grpdelip,do_site_help_grpdelip,TOK_SITE_GRPDELIP)) return -1;
   if (commands_add(_ctable,"site_grpkill",do_site_grpkill,NULL,TOK_SITE_GRPKILL)) return -1;
-  if (commands_add(_ctable,"site_grpratio",do_site_grpratio,NULL,TOK_SITE_GRPRATIO)) return -1;
-  if (commands_add(_ctable,"site_grpren",do_site_grpren,NULL,TOK_SITE_GRPREN)) return -1;
+  if (commands_add(_ctable,"site_grpratio",do_site_grpratio,do_site_help_grpratio,TOK_SITE_GRPRATIO)) return -1;
+  if (commands_add(_ctable,"site_grpren",do_site_grpren,do_site_help_grpren,TOK_SITE_GRPREN)) return -1;
   if (commands_add(_ctable,"site_gsinfo",do_site_gsinfo,NULL,TOK_SITE_GSINFO)) return -1;
+  if (commands_add(_ctable,"site_help",do_site_help_command,NULL,TOK_SITE_HELP)) return -1;
   if (commands_add(_ctable,"site_idle",do_site_idle,NULL,TOK_SITE_IDLE)) return -1;
   if (commands_add(_ctable,"site_invite",do_site_invite,NULL,TOK_SITE_INVITE)) return -1;
   if (commands_add(_ctable,"site_kick",do_site_kick,NULL,TOK_SITE_KICK)) return -1;
@@ -251,16 +289,17 @@ int commands_add_defaults(CHTBL * _ctable)
   if (commands_add(_ctable,"site_msg",do_site_msg,NULL,TOK_SITE_MSG)) return -1;
   if (commands_add(_ctable,"site_perm",do_site_perm,NULL,TOK_SITE_PERM)) return -1;
   if (commands_add(_ctable,"site_purge",do_site_purgeuser,NULL,TOK_SITE_PURGE)) return -1;
-  if (commands_add(_ctable,"site_readd",do_site_readduser,NULL,TOK_SITE_READD)) return -1;
+  if (commands_add(_ctable,"site_readd",do_site_readduser,do_site_help_readduser,TOK_SITE_READD)) return -1;
   if (commands_add(_ctable,"site_reload",do_site_reload,NULL,TOK_SITE_RELOAD)) return -1;
   if (commands_add(_ctable,"site_reopen",do_site,NULL,TOK_SITE_REOPEN)) return -1;
   if (commands_add(_ctable,"site_rusage",do_site_rusage,NULL,TOK_SITE_RUSAGE)) return -1;
   if (commands_add(_ctable,"site_savecfg",do_site_savecfg,NULL,TOK_SITE_SAVECFG)) return -1;
   if (commands_add(_ctable,"site_sections",do_site_sections,NULL,TOK_SITE_SECTIONS)) return -1;
+  if (commands_add(_ctable,"site_showlog",do_site_showlog,NULL,TOK_SITE_SHOWLOG)) return -1;
   if (commands_add(_ctable,"site_shutdown",do_site,NULL,TOK_SITE_SHUTDOWN)) return -1;
-  if (commands_add(_ctable,"site_su",do_site_su,NULL,TOK_SITE_SU)) return -1;
+  if (commands_add(_ctable,"site_su",do_site_su,do_site_help_su,TOK_SITE_SU)) return -1;
   if (commands_add(_ctable,"site_tagline",do_site_tagline,NULL,TOK_SITE_TAGLINE)) return -1;
-  if (commands_add(_ctable,"site_take",do_site_take,NULL,TOK_SITE_TAKE)) return -1;
+  if (commands_add(_ctable,"site_take",do_site_take,do_site_help_take,TOK_SITE_TAKE)) return -1;
 #ifdef DEBUG
   if (commands_add(_ctable,"site_test",do_site_test,NULL,TOK_SITE_TEST)) return -1;
 #endif
@@ -280,6 +319,15 @@ int commands_add_defaults(CHTBL * _ctable)
   return 0;
 }
 
+/** \brief Search for command in registered commands
+ *
+ * \param[in] _ctable Hash table containing commands
+ * \param[in] str Command name to find
+ *
+ * \return
+ * - a wzd_command_t structure if the command has been found
+ * - NULL if not found
+ */
 wzd_command_t * commands_find(CHTBL * _ctable, wzd_string_t *str)
 {
   wzd_command_t * command = NULL;
@@ -293,6 +341,16 @@ wzd_command_t * commands_find(CHTBL * _ctable, wzd_string_t *str)
   return command;
 }
 
+/** \brief Set permissions associated to a command
+ *
+ * Replace permissions for the specified command.
+ * The command must exist.
+ *
+ * \param[in] _ctable Hash table containing commands
+ * \param[in] permname The permission name
+ * \param[in] permline A string describing permissions
+ * \return 0 if command is ok
+ */
 int commands_set_permission(CHTBL * _ctable, const char * permname, const char * permline)
 {
   wzd_command_t * command;
@@ -316,6 +374,16 @@ int commands_set_permission(CHTBL * _ctable, const char * permname, const char *
   }
 }
 
+/** \brief Add permissions to a command
+ *
+ * Add permissions for the specified command.
+ * The command must exist.
+ *
+ * \param[in] _ctable Hash table containing commands
+ * \param[in] permname The permission name
+ * \param[in] permline A string describing permissions, to be appended
+ * \return 0 if command is ok
+ */
 int commands_add_permission(CHTBL * _ctable, const char * permname, const char * permline)
 {
   wzd_command_t * command;
@@ -328,6 +396,14 @@ int commands_add_permission(CHTBL * _ctable, const char * permname, const char *
   return perm_add_perm(permname, permline, &command->perms);
 }
 
+/** \brief Check if user is authorized to run specified command
+ *
+ * Check if the user in the specific context is allowed to run the command.
+ *
+ * \param[in] command The command name
+ * \param[in] context The client context
+ * \return 0 if ok
+ */
 int commands_check_permission(wzd_command_t * command, wzd_context_t * context)
 {
   if (!command) return 0;
@@ -335,6 +411,14 @@ int commands_check_permission(wzd_command_t * command, wzd_context_t * context)
   return perm_check_perm(command->perms, context);
 }
 
+/** \brief Delete permissions associated to a command
+ *
+ * Delete permissions associated to the command.
+ *
+ * \param[in] _ctable Hash table containing commands
+ * \param[in] str The command name
+ * \return 0 if ok
+ */
 int commands_delete_permission(CHTBL * _ctable, wzd_string_t * str)
 {
   wzd_command_t * command;
