@@ -96,6 +96,7 @@
 
 #include "wzd_structs.h"
 
+#include "wzd_ClientThread.h"
 #include "wzd_fs.h"
 #include "wzd_libmain.h"
 #include "wzd_log.h"
@@ -339,6 +340,7 @@ int get_device_info(const char *file, long * f_type, long * f_bsize, long * f_bl
     if (f_free) *f_free = df.avail_clusters * df.sectors_per_cluster;
     if (f_bsize) *f_bsize = df.bytes_per_sector;
     if (f_blocks) *f_blocks = df.total_clusters * df.sectors_per_cluster;
+    return 0;
   }
 #endif
 
@@ -726,7 +728,7 @@ wzd_bw_limiter * limiter_new(int maxspeed)
   return l_new;
 }
 
-void limiter_add_bytes(wzd_bw_limiter *l, wzd_mutex_t * mutex, int byte_count, int force_check)
+void limiter_add_bytes(wzd_bw_limiter *l, wzd_mutex_t * mutex, int byte_count, UNUSED int force_check)
 {
 #ifndef WIN32 /* FIXME VISUAL */
   struct timeval tv;
@@ -1089,31 +1091,43 @@ void * GetMyContext(void)
   ListElmt * elmnt;
   wzd_context_t * context=NULL;
 
-#ifdef WIN32
-  unsigned long thread_id;
+  /* first, try to get value from TLS */
+  context = _tls_get_context();
+  if (context != NULL) {
+    WZD_ASSERT_RETURN(context->magic == CONTEXT_MAGIC, NULL);
+    return context;
+  }
 
-  thread_id = (unsigned long)GetCurrentThreadId();
-  /* TODO search context list and cleanup context */
-  for (elmnt=list_head(context_list); elmnt!=NULL; elmnt=list_next(elmnt))
+  /* if not found, try iterating through context list */
+#ifdef WIN32
   {
-    context = list_data(elmnt);
-    if (context && context->magic == CONTEXT_MAGIC && context->thread_id == thread_id) {
-      return context;
+    unsigned long thread_id;
+
+    thread_id = (unsigned long)GetCurrentThreadId();
+    /* TODO search context list and cleanup context */
+    for (elmnt=list_head(context_list); elmnt!=NULL; elmnt=list_next(elmnt))
+    {
+      context = list_data(elmnt);
+      if (context && context->magic == CONTEXT_MAGIC && context->thread_id == thread_id) {
+        return context;
+      }
     }
   }
 #else /* WIN32 */
-  pthread_t thread_id;
-
-  if (!context_list) return NULL;
-
-  thread_id = pthread_self();
-  /* TODO search context list and cleanup context */
-  for (elmnt=list_head(context_list); elmnt!=NULL; elmnt=list_next(elmnt))
   {
-    context = list_data(elmnt);
-    if (context && context->magic == CONTEXT_MAGIC &&
-      pthread_equal((pthread_t)context->thread_id,thread_id)) {
-        return context;
+    pthread_t thread_id;
+
+    if (!context_list) return NULL;
+
+    thread_id = pthread_self();
+    /* TODO search context list and cleanup context */
+    for (elmnt=list_head(context_list); elmnt!=NULL; elmnt=list_next(elmnt))
+    {
+      context = list_data(elmnt);
+      if (context && context->magic == CONTEXT_MAGIC &&
+        pthread_equal((pthread_t)context->thread_id,thread_id)) {
+          return context;
+      }
     }
   }
 #endif /* WIN32 */
@@ -1154,5 +1168,53 @@ int win32_gettimeofday(struct timeval *tv, struct timezone *tz)
 
     return 0;
 }
+
+
+/** We can't use _chsize() since it is limited to 2Gb files, nor _chsize_s()
+ * which does not exist on all versions of the platform SDK.
+ */
+int win32_ftruncate(int fd, __int64 length)
+{
+  HANDLE handle = (HANDLE)_get_osfhandle(fd);
+  __int64 offset, offset_set;
+  __int32 offset_hi, length_hi;
+  int res;
+
+  /* save file pointer */
+  offset_hi = 0;
+  offset = SetFilePointer(handle, 0, &offset_hi, FILE_CURRENT);
+  if (offset == INVALID_SET_FILE_POINTER)
+    return -1;
+
+  /* extend or truncate */
+  length_hi = (__int32)(length >> 32);
+  offset_set = SetFilePointer(handle, (__int32)(length & 0xFFFFFFFF), &length_hi, FILE_BEGIN);
+  if (offset_set == INVALID_SET_FILE_POINTER)
+    return -1;
+
+  res = SetEndOfFile(handle);
+  if (res == FALSE)
+    return -1;
+
+  /* restore file pointer */
+  offset_set = SetFilePointer(handle, (__int32)(offset & 0xFFFFFFFF), &offset_hi, FILE_BEGIN);
+  if (offset_set == INVALID_SET_FILE_POINTER)
+    return -1;
+
+  return res;
+}
+
 #endif /* WIN32 */
 
+#ifndef HAVE_STRERROR
+const char *strerror(int errnum)
+{
+  static char buf[1024];
+
+  snprintf(buf,1023,"Unknown error %d\n",errnum);
+  buf[1023] = '\0';
+
+  return buf;
+}
+#endif /* HAVE_STRERROR */
+
