@@ -62,6 +62,7 @@
 #include "wzd_misc.h"
 #include "wzd_messages.h"
 #include "wzd_mod.h"
+#include "wzd_user.h"
 
 #include "wzd_debug.h"
 
@@ -85,10 +86,13 @@ struct event_entry_t event_tab[] = {
   { EVENT_POSTUPLOAD, "POSTUPLOAD" },
   { EVENT_PREDOWNLOAD, "PREDOWNLOAD" },
   { EVENT_POSTDOWNLOAD, "POSTDOWNLOAD" },
+  { EVENT_PREMKDIR, "PREMKDIR" },
   { EVENT_MKDIR, "MKDIR" },
   { EVENT_RMDIR, "RMDIR" },
   { EVENT_DELE, "DELE" },
   { EVENT_SITE, "SITE" },
+  { EVENT_WIPE, "WIPE" },
+  { EVENT_PREWIPE, "PREWIPE" },
   { 0, NULL },
 };
 
@@ -235,36 +239,6 @@ int hook_add_external(wzd_hook_t ** hook_list, unsigned long mask, const char *c
   return 0;
 }
 
-int hook_add_custom_command(wzd_hook_t ** hook_list, const char *name, const char *command)
-{
-  wzd_hook_t * current_hook, * new_hook;
-
-  new_hook = malloc(sizeof(wzd_hook_t));
-  if (!new_hook) return 1;
-
-  new_hook->mask = EVENT_SITE;
-  new_hook->hook = NULL;
-  new_hook->opt = strdup(name);
-  new_hook->external_command = strdup(command);
-  new_hook->next_hook = NULL;
-
-  current_hook = *hook_list;
-
-  if (!current_hook) {
-    *hook_list = new_hook;
-    return 0;
-  }
-
-  while (current_hook->next_hook) {
-    current_hook = current_hook->next_hook;
-  }
-
-  current_hook->next_hook = new_hook;
-
-  return 0;
-
-}
-
 /** remove hook from list */
 int hook_remove(wzd_hook_t **hook_list, unsigned long mask, void_fct hook)
 {
@@ -402,6 +376,7 @@ int module_check(const char *filename)
   char * error;
   fs_filestat_t st;
   int ret;
+  int mode = DL_ARG;
 
   if (!filename || filename[0]=='\0') return -1;
 #ifndef _MSC_VER
@@ -425,8 +400,13 @@ int module_check(const char *filename)
     return -1;
   }
 
+#ifdef RTLD_GLOBAL
+  mode |= RTLD_GLOBAL;
+#else
+  out_log(LEVEL_NORMAL,"WARNING Can't make loaded symbols global on this platform while loading %s\n",path);
+#endif
   /* test dlopen */
-  handle = dlopen(path,DL_ARG);
+  handle = dlopen(path,mode);
   if (!handle) {
     out_err(LEVEL_HIGH,"Could not dlopen module '%s'\n",filename);
     out_err(LEVEL_HIGH,"errno: %d error: %s\n",errno, strerror(errno));
@@ -508,6 +488,7 @@ int module_load(wzd_module_t *module)
   int ret;
   char * filename;
   fcn_module_init f_init;
+  int mode = DL_ARG;
 #ifdef DEBUG
   char * error;
 #endif
@@ -528,7 +509,13 @@ int module_load(wzd_module_t *module)
     strcpy(path+2,filename);
   }
 
-  handle = dlopen(path,DL_ARG);
+#ifdef RTLD_GLOBAL
+  mode |= RTLD_GLOBAL;
+#else
+  out_log(LEVEL_NORMAL,"WARNING Can't make loaded symbols global on this platform while loading %s\n",path);
+#endif
+  /* test dlopen */
+  handle = dlopen(path,mode);
   if (!handle) return -1;
 
   f_init = (fcn_module_init)dlsym(handle,DL_PREFIX STR_MODULE_INIT);
