@@ -72,16 +72,17 @@ void do_site_help(const char *site_command, wzd_context_t * context);
 
 
 
-void do_site_help_grpadd(wzd_context_t * context)
+int do_site_help_grpadd(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site grpadd <group> [<backend>]");
+  return 0;
 }
 
 /** site grpadd: adds a new group
  *
  * grpadd &lt;group&gt; [&lt;backend&gt;]
  */
-int do_site_grpadd(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_grpadd(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t *groupname;
   int err;
@@ -94,14 +95,13 @@ int do_site_grpadd(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
 
   groupname = str_tok(command_line," \t\r\n");
   if (!groupname) {
-    do_site_help_grpadd(context);
-    return 0;
+    return do_site_help_grpadd(cname,command_line,context);
   }
 
   /* Gadmin ? */
   if (is_gadmin)
   {
-    err = send_message_with_args(501,context,"Gadmins can't add groups !");
+    err = send_message_with_args(501,context,"Gadmins can't add groups!");
     str_deallocate(groupname);
     return 0;
   }
@@ -114,10 +114,10 @@ int do_site_grpadd(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
         err = send_message_with_args(501,context,"Invalid name or parameter");
         break;
       case E_PARAM_EXIST:
-        err = send_message_with_args(501,context,"A group already exist with this name");
+        err = send_message_with_args(501,context,"A group already exists with this name");
         break;
       default:
-        err = send_message_with_args(501,context,"Error while adding group");
+        err = send_message_with_args(501,context,"Error occured while creating group");
         break;
     }
     str_deallocate(groupname);
@@ -130,7 +130,7 @@ int do_site_grpadd(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   str_deallocate(groupname);
 
   if (err) {
-    err = send_message_with_args(501,context,"Problem adding group");
+    err = send_message_with_args(501,context,"Could not commit new group to backend");
     group_free(newgroup);
   } else {
     err = send_message_with_args(200,context,"Group added");
@@ -139,9 +139,10 @@ int do_site_grpadd(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   return 0;
 }
 
-void do_site_help_grpdel(wzd_context_t * context)
+int do_site_help_grpdel(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site grpdel <group> [<backend>]");
+  return 0;
 }
 
 
@@ -149,7 +150,7 @@ void do_site_help_grpdel(wzd_context_t * context)
  *
  * grpdel &lt;group&gt;
  */
-int do_site_grpdel(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_grpdel(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * groupname;
   int ret;
@@ -169,8 +170,7 @@ int do_site_grpdel(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
 
   groupname = str_tok(command_line," \t\r\n");
   if (!groupname) {
-    do_site_help_grpdel(context);
-    return 0;
+    return do_site_help_grpdel(cname,command_line,context);
   }
   /* TODO read backend */
 
@@ -224,15 +224,16 @@ int do_site_grpdel(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   return 0;
 }
 
-void do_site_help_grpren(wzd_context_t * context)
+int do_site_help_grpren(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site grpren <groupname> <newgroupname>");
+  return 0;
 }
 /** site grpren: rename group
  *
  * grpren oldname newname
  */
-int do_site_grpren(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_grpren(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * groupname, *newgroupname;
   int ret;
@@ -246,14 +247,12 @@ int do_site_grpren(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
 
   groupname = str_tok(command_line," \t\r\n");
   if (!groupname) {
-    do_site_help_grpren(context);
-    return 0;
+    return do_site_help_grpren(cname,command_line,context);
   }
   newgroupname = str_tok(command_line," \t\r\n");
   if (!newgroupname) {
-    do_site_help_grpren(context);
     str_deallocate(groupname);
-    return 0;
+    return do_site_help_grpren(cname,command_line,context);
   }
 
   /* check if group exists */
@@ -274,7 +273,7 @@ int do_site_grpren(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
 
   if (is_gadmin)
   {
-    ret = send_message_with_args(501,context,"GAdmins can't do that !");
+    ret = send_message_with_args(501,context,"GAdmins can't do that!");
     str_deallocate(newgroupname);
     return 0;
   }
@@ -293,7 +292,7 @@ int do_site_grpren(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   return 0;
 }
 
-int do_site_ginfo(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_ginfo(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * str;
   wzd_string_t * groupname;
@@ -315,7 +314,7 @@ int do_site_ginfo(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 
   str = config_get_string(mainConfig->cfg_file,"GLOBAL","sitefile_ginfo",NULL);
   if (!str) {
-    ret = send_message_with_args(501,context,"File [GLOBAL] / sitefile_ginfo does not exists");
+    ret = send_message_with_args(501,context,"File [GLOBAL] / sitefile_ginfo does not exist");
     return 0;
   }
 
@@ -327,7 +326,7 @@ int do_site_ginfo(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
   return 0;
 }
 
-int do_site_gsinfo(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_gsinfo(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * str;
   wzd_string_t * groupname;
@@ -349,7 +348,7 @@ int do_site_gsinfo(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
 
   str = config_get_string(mainConfig->cfg_file,"GLOBAL","sitefile_group",NULL);
   if (!str) {
-    ret = send_message_with_args(501,context,"File [GLOBAL] / sitefile_group does not exists");
+    ret = send_message_with_args(501,context,"File [GLOBAL] / sitefile_group does not exist");
     return 0;
   }
 
@@ -360,16 +359,17 @@ int do_site_gsinfo(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   return 0;
 }
 
-void do_site_help_grpaddip(wzd_context_t * context)
+int do_site_help_grpaddip(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site grpaddip <group> <ip>");
+  return 0;
 }
 
 /** site grpaddip: adds an ip to a group
  *
  * grpaddip &lt;group&gt; &lt;ip&gt;
  */
-int do_site_grpaddip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_grpaddip(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * groupname, *ip;
   int ret;
@@ -382,8 +382,7 @@ int do_site_grpaddip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
 
   groupname = str_tok(command_line," \t\r\n");
   if (!groupname) {
-    do_site_help_grpaddip(context);
-    return 0;
+    return do_site_help_grpaddip(cname,command_line,context);
   }
 
   /* check if group exists */
@@ -397,19 +396,18 @@ int do_site_grpaddip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
   /* GAdmin ? */
   if (is_gadmin)
   {
-    ret = send_message_with_args(501,context,"Gadmins can't do that !");
+    ret = send_message_with_args(501,context,"Gadmins can't do that!");
     return 0;
   }
 
   ip = str_tok(command_line," \t\r\n");
   if (!ip) {
-    do_site_help_grpaddip(context);
-    return 0;
+    return do_site_help_grpaddip(cname,command_line,context);
   }
 
   ret = ip_inlist(group->ip_list, str_tochar(ip));
   if (ret) {
-    ret = send_message_with_args(501,context,"ip is already included in list");
+    ret = send_message_with_args(501,context,"IP address is already included in list");
     str_deallocate(ip);
     return 0;
   }
@@ -420,14 +418,15 @@ int do_site_grpaddip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
   /* commit to backend */
   backend_mod_group(mainConfig->backends->filename,group->gid,group,_GROUP_IP);
 
-  ret = send_message_with_args(200,context,"Group ip added");
+  ret = send_message_with_args(200,context,"Group IP address added");
   return 0;
 }
 
-void do_site_help_grpdelip(wzd_context_t * context)
+int do_site_help_grpdelip(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_raw("501-Usage: site grpdelip <group> <ip>\r\n",context);
   send_message_raw("501  or: site grpdelip <grp> <slot_number> (get it with site gsinfo <group>)\r\n",context);
+  return 0;
 }
 
 /** site grpdelip: removes ip from group
@@ -436,7 +435,7 @@ void do_site_help_grpdelip(wzd_context_t * context)
  *
  * grpdelip &lt;group&gt; &lt;slot_number&gt;
  */
-int do_site_grpdelip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_grpdelip(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   char *ptr;
   wzd_string_t * groupname, *ip;
@@ -451,8 +450,7 @@ int do_site_grpdelip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
 
   groupname = str_tok(command_line," \t\r\n");
   if (!groupname) {
-    do_site_help_grpdelip(context);
-    return 0;
+    return do_site_help_grpdelip(cname,command_line,context);
   }
   /* check if group exists */
   group=GetGroupByName(str_tochar(groupname));
@@ -464,14 +462,13 @@ int do_site_grpdelip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
 
   ip = str_tok(command_line," \t\r\n");
   if (!ip) {
-    do_site_help_grpdelip(context);
-    return 0;
+    return do_site_help_grpdelip(cname,command_line,context);
   }
 
   /* GAdmin ? */
   if (is_gadmin)
   {
-    ret = send_message_with_args(501,context,"Gadmins can't do that !");
+    ret = send_message_with_args(501,context,"Gadmins can't do that!");
     str_deallocate(ip);
     return 0;
   }
@@ -502,7 +499,7 @@ int do_site_grpdelip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
       return 0;
     }
     backend_mod_group(mainConfig->backends->filename,group->gid,group,_GROUP_IP);
-    ret = send_message_with_args(200,context,"Group ip removed");
+    ret = send_message_with_args(200,context,"Group IP address removed");
     return 0;
   } /* if (*ptr=='\0') */
 
@@ -518,20 +515,22 @@ int do_site_grpdelip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
 
   /* commit to backend */
   backend_mod_group(mainConfig->backends->filename,group->gid,group,_GROUP_IP);
-  ret = send_message_with_args(200,context,"Group ip removed");
+  ret = send_message_with_args(200,context,"Group IP address removed");
 
   return 0;
 }
 
-void do_site_help_grpratio(wzd_context_t * context)
+int do_site_help_grpratio(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site grpratio <group> <ratio>");
+  return 0;
 }
+
 /** site grpratio: change group ratio
  *
  * grpratio group ratio
  */
-int do_site_grpratio(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_grpratio(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   char *ptr;
   wzd_string_t * str_ratio, *groupname;
@@ -546,8 +545,7 @@ int do_site_grpratio(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
 
   groupname = str_tok(command_line," \t\r\n");
   if (!groupname) {
-    do_site_help_grpratio(context);
-    return 0;
+    return do_site_help_grpratio(cname,command_line,context);
   }
   /* check if group exists */
   group=GetGroupByName(str_tochar(groupname));
@@ -559,21 +557,19 @@ int do_site_grpratio(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
 
   str_ratio = str_tok(command_line," \t\r\n");
   if (!str_ratio) {
-    do_site_help_grpratio(context);
-    return 0;
+    return do_site_help_grpratio(cname,command_line,context);
   }
 
   ratio = strtoul(str_tochar(str_ratio),&ptr,0);
   if (*ptr!='\0') {
-    do_site_help_grpratio(context);
     str_deallocate(str_ratio);
-    return 0;
+    return do_site_help_grpratio(cname,command_line,context);
   }
   str_deallocate(str_ratio);
 
   if (is_gadmin)
   {
-    ret = send_message_with_args(501,context,"GAdmins can't do that !");
+    ret = send_message_with_args(501,context,"GAdmins can't do that!");
     return 0;
   }
 
@@ -594,7 +590,7 @@ int do_site_grpratio(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
  *
  * grpkill group
  */
-int do_site_grpkill(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_grpkill(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   ListElmt * elmnt;
   wzd_context_t * loop_context;
@@ -630,14 +626,14 @@ int do_site_grpkill(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
     }
   }
 
-  if (!found) { ret = send_message_with_args(501,context,"No member found !"); }
+  if (!found) { ret = send_message_with_args(501,context,"No member found!"); }
   else { ret = send_message_with_args(200,context,"KILL signal sent"); }
 
   return 0;
 }
 
 
-void do_site_help_grpchange(wzd_context_t * context)
+int do_site_help_grpchange(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_raw("501-site grpchange <group> <field> <value>\r\n",context);
   send_message_raw("field can be one of:\r\n",context);
@@ -652,13 +648,15 @@ void do_site_help_grpchange(wzd_context_t * context)
   send_message_raw(" num_logins  changes maximum simultaneous logins allowed\r\n",context);
 
   send_message_raw("501 site grpchange aborted\r\n",context);
+
+  return 0;
 }
 
 /** site grpchange: change a field for a group
  *
  * grpchange &lt;group&gt; &lt;field&gt; &lt;value&gt;
  */
-int do_site_grpchange(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_grpchange(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   char *ptr;
   wzd_string_t * groupname, * field, * value;
@@ -671,25 +669,21 @@ int do_site_grpchange(wzd_string_t *ignored, wzd_string_t *command_line, wzd_con
   me = GetUserByID(context->userid);
 
   if (!command_line) {
-    do_site_help_grpchange(context);
-    return 0;
+    return do_site_help_grpchange(cname,command_line,context);
   }
   groupname = str_tok(command_line," \t\r\n");
   if (!groupname) {
-    do_site_help_grpchange(context);
-    return 0;
+    return do_site_help_grpchange(cname,command_line,context);
   }
   field = str_tok(command_line," \t\r\n");
   if (!field) {
-    do_site_help_grpchange(context);
     str_deallocate(groupname);
-    return 0;
+    return do_site_help_grpchange(cname,command_line,context);
   }
   value = str_tok(command_line,"\r\n");
   if (!value) {
-    do_site_help_grpchange(context);
     str_deallocate(groupname); str_deallocate(field);
-    return 0;
+    return do_site_help_grpchange(cname,command_line,context);
   }
 
   /* check if group exists */
@@ -771,7 +765,7 @@ int do_site_grpchange(wzd_string_t *ignored, wzd_string_t *command_line, wzd_con
   }
   else {
     str_deallocate(field); str_deallocate(value);
-    ret = send_message_with_args(501,context,"syntax error, unknow field");
+    ret = send_message_with_args(501,context,"Syntax error, unknown field");
     return 0;
   }
 
@@ -783,13 +777,13 @@ int do_site_grpchange(wzd_string_t *ignored, wzd_string_t *command_line, wzd_con
   if (ret)
     ret = send_message_with_args(501,context,"Problem occured when committing");
   else
-    ret = send_message_with_args(200,context,"Group field change successfull");
+    ret = send_message_with_args(200,context,"Group field change successful");
 
   return 0;
 }
 
 
-void do_site_help_group(wzd_context_t * context)
+int do_site_help_group(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_raw("501-site group <action> ...\r\n",context);
   send_message_raw("action can be one of:\r\n",context);
@@ -806,10 +800,12 @@ void do_site_help_group(wzd_context_t * context)
   send_message_raw(" list       list all existing groups\r\n",context);
   send_message_raw("use site <action> for specific action help\r\n",context);
   send_message_raw("501 site group aborted\r\n",context);
+
+  return 0;
 }
 
 /* regroup all group administration in one site command */
-int do_site_group(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_group(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
 
   wzd_string_t * cmd;
@@ -819,8 +815,7 @@ int do_site_group(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
   cmd = str_tok(command_line," \t\r\n");
 
   if( cmd == NULL ) {
-    do_site_help_group(context);
-    return 0;
+    return do_site_help_group(cname,command_line,context);
   }
 
   if(strcmp("info", str_tochar(cmd)) == 0) {
