@@ -315,6 +315,13 @@ int tls_exit(void)
   if (CFG_GET_OPTION(mainConfig,CFG_OPT_DISABLE_TLS)) {
     return 0;
   }
+  EVP_cleanup();
+  CRYPTO_cleanup_all_ex_data();
+
+  ERR_clear_error();
+  ERR_remove_state(0);
+
+  ERR_free_strings();
 
   SSL_CTX_free(mainConfig->tls_ctx);
   return 0;
@@ -752,6 +759,8 @@ int tls_free(wzd_context_t * context)
   }
   context->ssl->obj = NULL;
 
+  ERR_remove_state(0);
+  ERR_clear_error();
   return 0;
 }
 
@@ -777,6 +786,11 @@ GCRY_THREAD_OPTION_PTHREAD_IMPL;
 
 #include <fcntl.h>
 
+/** \warning setting this value to > 512 will cause problems for compatibility
+ * with OpenSSL
+ */
+#define SERVER_DH_BITS 768
+#define CLIENT_DH_BITS 512
 
 #define DH_BITS 1024
 
@@ -808,7 +822,7 @@ static int generate_dh_params(void)
    * security requirements.
    */
   gnutls_dh_params_init(&dh_params);
-  gnutls_dh_params_generate2(dh_params, DH_BITS);
+  gnutls_dh_params_generate2(dh_params, SERVER_DH_BITS);
 
   return 0;
 }
@@ -830,7 +844,7 @@ int tls_dh_params_regenerate(void)
     return -1;
   }
 
-  gnutls_dh_params_generate2(new, DH_BITS);
+  gnutls_dh_params_generate2(new, SERVER_DH_BITS);
 
   WZD_MUTEX_LOCK(SET_MUTEX_GLOBAL);
   tmp = dh_params;
@@ -842,7 +856,7 @@ int tls_dh_params_regenerate(void)
 
   gnutls_dh_params_deinit(tmp);
 
-  out_log(LEVEL_INFO,"- Regenerated %d bits Diffie-Hellman key for TLS.\n", DH_BITS);
+  out_log(LEVEL_INFO,"- Regenerated %d bits Diffie-Hellman key for TLS.\n", SERVER_DH_BITS);
 
   return 0;
 }
@@ -954,7 +968,7 @@ static gnutls_session initialize_tls_session(gnutls_connection_end con_end)
     gnutls_certificate_server_set_request(session, GNUTLS_CERT_REQUEST);
   }
 
-  gnutls_dh_set_prime_bits(session, DH_BITS);
+  gnutls_dh_set_prime_bits(session, CLIENT_DH_BITS); /* OpenSSL will not be able to support more */
 
   return session;
 }
