@@ -1,8 +1,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <wzd_structs.h>
-#include <wzd_vfs.h>
+#include <libwzd-core/wzd_structs.h>
+#include <libwzd-core/wzd_vfs.h>
 
 #define C1 0x12345678
 #define C2 0x9abcdef0
@@ -45,6 +45,7 @@ int main(int argc, char *argv[])
     "/d/toto/../../e", "/e",
     "/dir.", "/dir.",
     "/dir..", "/dir..",
+    "/dir/..", "/",
     NULL, NULL
   };
 
