@@ -75,6 +75,11 @@
 #define INET6_ADDRSTRLEN 46
 #endif
 
+/** \todo XXX FIXME remove this line and use correct types !!!!
+ * this is used to convert char* to struct in6_addr
+ */
+#define PORCUS_CAST(x) ( ((struct in6_addr*)(x)) )
+
 #include <libwzd-core/wzd_structs.h>
 
 #include <libwzd-core/wzd_misc.h>
@@ -224,20 +229,31 @@ void reset_stats(wzd_server_stat_t * stats)
 }
 
 /** \return 1 if ip is ok, 0 if ip is denied, -1 if ip is not in list or on error */
-static int global_check_ip_allowed(unsigned char *userip)
+static int global_check_ip_allowed(unsigned char *userip, net_family_t family)
 {
-  char ip[INET6_ADDRSTRLEN];
+  char ipv6[INET6_ADDRSTRLEN] = {0};
+  char ipv4[INET_ADDRSTRLEN] = {0};
+  int ret = -1;
 
   /** \warning If no ip was specified (ok or denied), then the default is to allow */
   if (mainConfig->login_pre_ip_checks == NULL) return 1;
 
-#if !defined(IPV6_SUPPORT)
-  inet_ntop(AF_INET,userip,ip,INET_ADDRSTRLEN);
-#else
-  inet_ntop(AF_INET6,userip,ip,INET6_ADDRSTRLEN);
+#if defined(IPV6_SUPPORT)
+  if (family == WZD_INET6) {
+    inet_ntop(AF_INET6,userip,ipv6,INET6_ADDRSTRLEN);
+    ret = ip_list_check(mainConfig->login_pre_ip_checks,ipv6);
+    if (ret == 0 && IN6_IS_ADDR_V4MAPPED(PORCUS_CAST(userip))) {
+      inet_ntop(AF_INET,userip,ipv4,INET_ADDRSTRLEN);
+      ret = ip_list_check(mainConfig->login_pre_ip_checks,ipv4);
+    }
+  } else
 #endif
+  {
+    inet_ntop(AF_INET,userip,ipv4,INET_ADDRSTRLEN);
+    ret = ip_list_check(mainConfig->login_pre_ip_checks,ipv4);
+  }
 
-  return ip_list_check(mainConfig->login_pre_ip_checks,ip);
+  return ret;
 }
 
 void server_rebind(const char *new_ip, unsigned int new_port)
@@ -515,7 +531,7 @@ static int server_add_ident_candidate(fd_t socket_accept_fd)
   }
 
   /* Here we check IP BEFORE starting session */
-  if (global_check_ip_allowed(userip)<=0) { /* IP was rejected */
+  if (global_check_ip_allowed(userip, family)<=0) { /* IP was rejected */
     /* close socket without warning ! */
     socket_close(newsock);
     FD_UNREGISTER(newsock,"Client socket");
@@ -968,9 +984,9 @@ void interrupt(int signum)
   /* closing properly ?! */
 #ifdef DEBUG
 #if !defined(WIN32) && !defined(__sun__)
-fprintf(stderr,"Received signal %s\n",sys_siglist[signum]);
+out_err(LEVEL_NORMAL,"Received signal %s\n",sys_siglist[signum]);
 #else
-fprintf(stderr,"Received signal %d\n",signum);
+out_err(LEVEL_NORMAL,"Received signal %d\n",signum);
 #endif
 #endif
   /* commit backend changes */
@@ -1309,7 +1325,6 @@ int server_switch_to_config(wzd_config_t *config)
       snprintf(buf,64,"%ld\n",(unsigned long)getpid());
       if (fd==-1) {
         out_log(LEVEL_CRITICAL,"Unable to open pid file %s: %s\n",config->pid_file,strerror(errno));
-        cfg_free(config);
         return -1;
       }
       ret = write(fd,buf,strlen(buf));
@@ -1339,7 +1354,7 @@ int server_switch_to_config(wzd_config_t *config)
  */
 int serverMainThreadProc(void *arg)
 {
-  int ret;
+  int ret, err;
   unsigned long max_wait_time;
   fd_set r_fds, w_fds, e_fds;
   fd_t maxfd;
@@ -1395,19 +1410,8 @@ int serverMainThreadProc(void *arg)
   }
 #endif /* POSIX */
 
-#ifndef _WIN32
-#if defined(DEBUG) && !defined(__CYGWIN__)
+#if defined(DEBUG) && !defined(WIN32)
   signal(SIGSEGV,server_crashed);
-#else
-  {
-    struct rlimit rlim;
-
-    /* no core file ! */
-    getrlimit(RLIMIT_CORE, &rlim);
-    rlim.rlim_cur = 0;
-    setrlimit(RLIMIT_CORE, &rlim);
-  }
-#endif
 #endif /* _WIN32 */
 
 #ifdef WIN32
@@ -1447,7 +1451,19 @@ int serverMainThreadProc(void *arg)
     return -1;
   }
 
+#ifndef WIN32
+  ret = config_get_boolean(mainConfig->cfg_file, "GLOBAL", "disable core", &err);
+  if (err == CF_OK && (ret)) {
+    struct rlimit rlim;
 
+    out_log(LEVEL_INFO,"INFO disabling core files\n");
+
+    /* no core file ! */
+    getrlimit(RLIMIT_CORE, &rlim);
+    rlim.rlim_cur = 0;
+    setrlimit(RLIMIT_CORE, &rlim);
+  }
+#endif
 
   /* clear ident list */
   list_init(&server_ident_list, free);
@@ -1639,11 +1655,11 @@ void serverMainThreadCleanup(int retcode)
         if (child_count == 0) { ok=1; break; }
         out_log(LEVEL_FLOOD,"Found %d child threads, waiting ..\n",child_count);
 #ifndef WIN32
-        usleep(300000);
+        usleep(1000000);
 #else
-        Sleep(300);
+        Sleep(1000);
 #endif
-        if (++loop_count > 10) { /* maximum wait time: ~ 3s */
+        if (++loop_count > 20) { /* maximum wait time: ~ 20s */
           out_log(LEVEL_INFO,"Still %d childs .. exiting anyway\n",child_count);
           break;
         }
