@@ -52,6 +52,8 @@
 #include <winsock2.h>
 
 #include "../visual/gnu_regex/regex.h"
+
+#include <Windows.h>
 #else
 #include <unistd.h>
 
@@ -249,7 +251,8 @@ int main_parse_args(int argc, char **argv)
         optindex++;
         continue;
       }
-      if (!strcmp(argv[optindex],"-h")) {
+      if (!strcmp(argv[optindex],"-h") || !strcmp(argv[optindex],"--help")
+		  || !strcmp(argv[optindex],"/?") || !strcmp(argv[optindex],"-?")) {
         display_usage();
         exit (0);
       }
@@ -304,6 +307,12 @@ int main(int argc, char **argv)
   wzd_config_t * config;
   wzd_configfile_t * cf;
 
+  /* register wzdftpd mutex so the installer/other programs can check if wzdftpd is active */
+#ifdef WIN32
+  CreateMutex(NULL,FALSE,"wzdftpdIsActive");
+  CreateMutex(NULL,FALSE,"Global\\wzdftpdIsActive");
+#endif
+
   wzd_debug_init();
 
 
@@ -363,7 +372,7 @@ int main(int argc, char **argv)
           if (!ret) {
             int err;
 
-            out_err(LEVEL_FLOOD,"config: NEW format found\n");
+            out_err(LEVEL_INFO,"config: NEW format found [%s]\n",config_files[i]);
 
             config = cfg_store(cf,&err);
             if (config) {
@@ -421,7 +430,7 @@ int main(int argc, char **argv)
     if (!ret) {
       int err;
 
-      out_err(LEVEL_INFO,"config: NEW format found\n");
+      out_err(LEVEL_INFO,"config: NEW format found [%s]\n",config_files[i]);
 
       config = cfg_store(cf,&err);
       if (config) {
@@ -432,13 +441,9 @@ int main(int argc, char **argv)
     config_free(cf);
     if (!ret) break;
   }
-  if (!config) {
-    fprintf(stderr,"FATAL: No valid config file found, aborting !\n");
-    exit(1);
-  }
-
 
   if (!config) {
+    fprintf(stderr,"FATAL: No valid config file found, aborting!\n");
     out_err(LEVEL_CRITICAL,"FATAL: Critical error loading config file, aborting\n");
     exit(1);
   }
